﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.MySqlPlus
{
    /// <summary>
    /// The outline of a MySqlColumn converter that converts a DateTime to Unix and back.
    /// </summary>
    public class DateTimeToUnixConverter : MySqlColumnConverter
    {
        /// <summary>
        /// Returns the MySql Type this converter converts to.
        /// </summary>
        public string ConvertToType { get { return "BIGINT UNSIGNED"; } }

        /// <summary>
        /// Converts from a Unix Time to a DateTime.
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotSupportedException"></exception>
        public object ConvertFrom(object input)
        {
            if (input is ulong unix)
            {
                if (unix == 0)
                    return DateTime.MinValue;

                return new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc).AddSeconds(unix).ToUniversalTime();
            }
            else
            {
                throw new NotSupportedException("Unsupported input object to convert from unix.");
            }
        }

        /// <summary>
        /// Converts to a Unix Time from a DateTime.
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotSupportedException"></exception>
        public object ConvertTo(object input)
        {
            if (input is DateTime dateTime)
            {
                if (dateTime == DateTime.MinValue)
                    return 0;

                if (dateTime == DateTime.MaxValue)
                    return ulong.MaxValue;

                return (ulong)(dateTime.ToUniversalTime().Subtract(new DateTime(1970, 1, 1, 0, 0, 0, DateTimeKind.Utc))).TotalSeconds;
            }
            else if (input is int inputInt)
            {
                return (ulong)inputInt;
            }
            else
            {
                throw new NotSupportedException("Unsupported input object to convert to unix.");
            }
        }
    }
}
